
**(Semi) Automated Image Processing**


.. image:: https://img.shields.io/badge/Made%20with-Python-1f425f.svg
   :target: https://www.python.org/
   :alt: made-with-python


.. image:: https://img.shields.io/github/issues/Nelson-Gon/simplecv.svg
   :target: https://GitHub.com/Nelson-Gon/simplecv/issues/
   :alt: GitHub issues


.. image:: https://img.shields.io/github/issues-closed/Nelson-Gon/simplecv.svg
   :target: https://GitHub.com/Nelson-Gon/simplecv/issues?q=is%3Aissue+is%3Aclosed
   :alt: GitHub issues-closed


.. image:: https://img.shields.io/badge/license-MIT-blue.svg
   :target: https://github.com/Nelson-Gon/simplecv/blob/master/LICENSE
   :alt: license


**Project Aims**

The goal of simple cv is to provide a simple computer vision(cv) workflow that enables one to automate 
or at least reduce the time spent in image (pre)-processing. 

**Installing the package**

.. code-block::

   # only if you can see releases >= 1
   pip install pip install git+https://github.com/Nelson-Gon/simplecv.git
   # clone the repo
   git clone https://www.github.com/Nelson-Gon/simplecv.git
   cd simplecv
   python3 setup.py install
